summaryrefslogtreecommitdiffstats
path: root/polkittqt1-version.h.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'polkittqt1-version.h.cmake')
-rw-r--r--polkittqt1-version.h.cmake36
1 files changed, 18 insertions, 18 deletions
diff --git a/polkittqt1-version.h.cmake b/polkittqt1-version.h.cmake
index 3d93c8846..61cacaec3 100644
--- a/polkittqt1-version.h.cmake
+++ b/polkittqt1-version.h.cmake
@@ -18,22 +18,22 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef _POLKITTQT1_VERSION_H_
-#define _POLKITTQT1_VERSION_H_
+#ifndef _POLKIT_TQT_VERSION_H_
+#define _POLKIT_TQT_VERSION_H_
#include "polkit-tqt-export.h"
/// @brief PolkitTQt-1 version as string at compile time.
-#define POLKITTQT1_VERSION_STRING "${POLKITTQT-1_VERSION_STRING}"
+#define POLKIT_TQT_VERSION_STRING "${POLKITTQT-1_VERSION_STRING}"
/// @brief The major PolkitTQt-1 version number at compile time
-#define POLKITTQT1_VERSION_MAJOR ${POLKITTQT-1_VERSION_MAJOR}
+#define POLKIT_TQT_VERSION_MAJOR ${POLKITTQT-1_VERSION_MAJOR}
/// @brief The minor PolkitTQt-1 version number at compile time
-#define POLKITTQT1_VERSION_MINOR ${POLKITTQT-1_VERSION_MINOR}
+#define POLKIT_TQT_VERSION_MINOR ${POLKITTQT-1_VERSION_MINOR}
/// @brief The PolkitTQt-1 patch version number at compile time
-#define POLKITTQT1_VERSION_PATCH ${POLKITTQT-1_VERSION_PATCH}
+#define POLKIT_TQT_VERSION_PATCH ${POLKITTQT-1_VERSION_PATCH}
/**
* \brief Create a unique number from the major, minor and release number of a %PolkitTQt-1 version
@@ -41,24 +41,24 @@
* This function can be used for preprocessing. For version information at runtime
* use the version methods in the PolkitTQt-1 namespace.
*/
-#define POLKITTQT1_MAKE_VERSION( a,b,c ) (((a) << 16) | ((b) << 8) | (c))
+#define POLKIT_TQT_MAKE_VERSION( a,b,c ) (((a) << 16) | ((b) << 8) | (c))
/**
* \brief %PolkitTQt-1 Version as a unique number at compile time
*
* This macro calculates the %PolkitTQt-1 version into a number. It is mainly used
* through POLKITTQT1_IS_VERSION in preprocessing. For version information at runtime
* use the version methods in the PolkitTQt-1 namespace.
*/
-#define POLKITTQT1_VERSION \
- POLKITTQT1_MAKE_VERSION(POLKITTQT1_VERSION_MAJOR,POLKITTQT1_VERSION_MINOR,POLKITTQT1_VERSION_PATCH)
+#define POLKIT_TQT_VERSION \
+ POLKIT_TQT_MAKE_VERSION(POLKIT_TQT_VERSION_MAJOR,POLKIT_TQT_VERSION_MINOR,POLKIT_TQT_VERSION_PATCH)
/**
* \brief Check if the %PolkitTQt-1 version matches a certain version or is higher
*
* This macro is typically used to compile conditionally a part of code:
* \code
- * #if POLKITTQT1_IS_VERSION(2,1)
+ * #if POLKIT_TQT_IS_VERSION(2,1)
* // Code for PolkitTQt-1 2.1
* #else
* // Code for PolkitTQt-1 2.0
@@ -68,39 +68,39 @@
* For version information at runtime
* use the version methods in the PolkitTQt-1 namespace.
*/
-#define POLKITTQT1_IS_VERSION(a,b,c) ( POLKITTQT1_VERSION >= POLKITTQT1_MAKE_VERSION(a,b,c) )
+#define POLKIT_TQT_IS_VERSION(a,b,c) ( POLKIT_TQT_VERSION >= POLKIT_TQT_MAKE_VERSION(a,b,c) )
-namespace PolkitTQt1 {
+namespace PolkitTQt {
/**
* @brief Returns the major number of PolkitTQt-1's version, e.g.
* 1 for %PolkitTQt-1 1.0.2.
* @return the major version number at runtime.
*/
- POLKITTQT1_EXPORT unsigned int versionMajor();
+ POLKIT_TQT_EXPORT unsigned int versionMajor();
/**
* @brief Returns the minor number of PolkitTQt-1's version, e.g.
* 0 for %PolkitTQt-1 1.0.2.
* @return the minor version number at runtime.
*/
- POLKITTQT1_EXPORT unsigned int versionMinor();
+ POLKIT_TQT_EXPORT unsigned int versionMinor();
/**
* @brief Returns the patch number of PolkitTQt-1's version, e.g.
* 2 for %PolkitTQt-1 1.0.2.
* @return the release number at runtime.
*/
- POLKITTQT1_EXPORT unsigned int versionPatch();
+ POLKIT_TQT_EXPORT unsigned int versionPatch();
/**
* @brief Returns the %PolkitTQt-1 version as string, e.g. "1.0.2".
*
* On contrary to the macro POLKITTQT1_VERSION_STRING this function returns
* the version number of PolkitTQt-1 at runtime.
* @return the %PolkitTQt-1 version. You can keep the string forever
*/
- POLKITTQT1_EXPORT const char* versionString();
+ POLKIT_TQT_EXPORT const char* versionString();
}
#endif
@@ -41,24 +41,24 @@
*
* This macro calculates the %PolkitTQt-1 version into a number. It is mainly used
- * through POLKITTQT1_IS_VERSION in preprocessing. For version information at runtime
+ * through POLKIT_TQT_IS_VERSION in preprocessing. For version information at runtime
* use the version methods in the PolkitTQt-1 namespace.
*/
@@ -68,39 +68,39 @@
* @brief Returns the %PolkitTQt-1 version as string, e.g. "1.0.2".
*
- * On contrary to the macro POLKITTQT1_VERSION_STRING this function returns
+ * On contrary to the macro POLKIT_TQT_VERSION_STRING this function returns
* the version number of PolkitTQt-1 at runtime.
* @return the %PolkitTQt-1 version. You can keep the string forever